==> common-1.3.0.8-sources.jar: cn/gtmap/gtc/workflow/domain/manage/UserTaskDto.java <==
package cn.gtmap.gtc.workflow.domain.manage;

import java.io.Serializable;
import java.util.List;

/**
 * @author <a href="mailto:yuxinwang@gtmap.cn">yxw</a>
 * @version 1.0, 2018/6/11
 * @Description: 流程节点实体
 *
 */

public class UserTaskDto implements Serializable {
    //节点活动id
    protected String id;
    //节点名称
    protected String name;
    //处理人
    protected String assignee;
    //流程委托人
    protected String owner;
    //优先级
    protected String priority;
    //表单key
    protected String formKey;
    //到期时间
    protected String dueDate;
    //流程业务类别
    protected String category;

    protected List<String> candidateUsers;
    protected List<String> candidateGroups;
    protected List<FormPropertyDto> formProperties;

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getAssignee() {
        return assignee;
    }

    public void setAssignee(String assignee) {
        this.assignee = assignee;
    }

    public String getOwner() {
        return owner;
    }

    public void setOwner(String owner) {
        this.owner = owner;
    }

    public String getPriority() {
        return priority;
    }

    public void setPriority(String priority) {
        this.priority = priority;
    }

    public String getFormKey() {
        return formKey;
    }

    public void setFormKey(String formKey) {
        this.formKey = formKey;
    }

    public String getDueDate() {
        return dueDate;
    }

    public void setDueDate(String dueDate) {
        this.dueDate = dueDate;
    }

    public String getCategory() {
        return category;
    }

    public void setCategory(String category) {
        this.category = category;
    }

    public List<String> getCandidateUsers() {
        return candidateUsers;
    }

    public void setCandidateUsers(List<String> candidateUsers) {
        this.candidateUsers = candidateUsers;
    }

    public List<String> getCandidateGroups() {
        return candidateGroups;
    }

    public void setCandidateGroups(List<String> candidateGroups) {
        this.candidateGroups = candidateGroups;
    }

    public List<FormPropertyDto> getFormProperties() {
        return formProperties;
    }

    public void setFormProperties(List<FormPropertyDto> formProperties) {
        this.formProperties = formProperties;
    }
}

==> common-1.3.0.66-sources.jar: cn/gtmap/gtc/workflow/domain/manage/UserTaskDto.java <==
package cn.gtmap.gtc.workflow.domain.manage;

import java.io.Serializable;
import java.util.List;

/**
 * @author <a href="mailto:yuxinwang@gtmap.cn">yxw</a>
 * @version 1.0, 2018/6/11
 * @Description: 流程节点实体
 *
 */

public class UserTaskDto implements Serializable {
    //节点活动id
    protected String id;
    //节点名称
    protected String name;
    //处理人
    protected String assignee;
    //流程委托人
    protected String owner;
    //优先级
    protected String priority;
    //表单key
    protected String formKey;
    //到期时间
    protected String dueDate;
    //流程业务类别
    protected String category;

    private Integer sort;

    protected List<String> candidateUsers;
    protected List<String> candidateGroups;
    protected List<FormPropertyDto> formProperties;




    public Integer getSort() {
        return sort;
    }

    public void setSort(Integer sort) {
        this.sort = sort;
    }

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getAssignee() {
        return assignee;
    }

    public void setAssignee(String assignee) {
        this.assignee = assignee;
    }

    public String getOwner() {
        return owner;
    }

    public void setOwner(String owner) {
        this.owner = owner;
    }

    public String getPriority() {
        return priority;
    }

    public void setPriority(String priority) {
        this.priority = priority;
    }

    public String getFormKey() {
        return formKey;
    }

    public void setFormKey(String formKey) {
        this.formKey = formKey;
    }

    public String getDueDate() {
        return dueDate;
    }

    public void setDueDate(String dueDate) {
        this.dueDate = dueDate;
    }

    public String getCategory() {
        return category;
    }

    public void setCategory(String category) {
        this.category = category;
    }

    public List<String> getCandidateUsers() {
        return candidateUsers;
    }

    public void setCandidateUsers(List<String> candidateUsers) {
        this.candidateUsers = candidateUsers;
    }

    public List<String> getCandidateGroups() {
        return candidateGroups;
    }

    public void setCandidateGroups(List<String> candidateGroups) {
        this.candidateGroups = candidateGroups;
    }

    public List<FormPropertyDto> getFormProperties() {
        return formProperties;
    }

    public void setFormProperties(List<FormPropertyDto> formProperties) {
        this.formProperties = formProperties;
    }
}
